@@ -8,5 +8,7 @@ from .guild_member import GuildMember, QueryParams
 from .guild_role import RoleUpdateInfo
 from .message import CreateDirectMessageRequest, MessageSendRequest, Message
 from .mute import MuteOption
+from .schedule import ScheduleToCreate, ScheduleToPatch
 from .token import Token
 from .user import ReqOption
+from .reaction import *
